@@ -18,13 +18,11 @@
 """Extensions to standard Python's heapq for performance applications."""
 
 __title__ = "thoth-adviser"
-__version__ = "0.1.3"
+__version__ = "0.2.0"
 __author__ = "Fridolin Pokorny <fridolin@redhat.com>"
 
-from .edict import ExtDict
 from .eheapq import ExtHeapQueue
 
 __all__ = [
-    "ExtDict",
     "ExtHeapQueue",
 ]
